pub enum SocResetReason {
Show 19 variants
ChipPowerOn = 1,
CoreSw = 3,
CoreDeepSleep = 5,
CpuPmuPwrDown = 6,
CoreMwdt0 = 7,
CoreMwdt1 = 8,
CoreRwdt = 9,
CpuMwdt = 11,
CpuSw = 12,
CpuRwdt = 13,
SysBrownOut = 15,
SysRwdt = 16,
SysSuperWdt = 18,
CorePwrGlitch = 19,
CoreEfuseCrc = 20,
CoreUsbJtag = 22,
CoreUsbUart = 23,
CpuJtag = 24,
CpuLockup = 26,
}unstable only.Expand description
SOC Reset Reason.
Variants
ChipPowerOn = 1
Power on reset
In ESP-IDF this value (0x01) can also be ChipBrownOut or
ChipSuperWdt, however that is not really compatible with Rust-style
enums.
CoreSw = 3
Software resets the digital core
CoreDeepSleep = 5
Deep sleep reset the digital core (also: PMU HP power down core reset)
CpuPmuPwrDown = 6
PMU HP CPU power down reset
CoreMwdt0 = 7
Main watch dog 0 resets digital core
CoreMwdt1 = 8
Main watch dog 1 resets digital core
CoreRwdt = 9
RWDT core reset
CpuMwdt = 11
MWDT HP CPU reset
CpuSw = 12
Software resets HP CPU
CpuRwdt = 13
RWDT resets digital core
SysBrownOut = 15
VDD voltage is not stable and resets the digital core
SysRwdt = 16
RWDT system reset
SysSuperWdt = 18
Super watch dog resets the digital core and rtc module
CorePwrGlitch = 19
Glitch on power resets the digital core and rtc module
CoreEfuseCrc = 20
eFuse CRC error resets the digital core
CoreUsbJtag = 22
USB Serial/JTAG controller’s JTAG resets the digital core
CoreUsbUart = 23
USB Serial/JTAG controller’s UART resets the digital core
CpuJtag = 24
JTAG resets the CPU
CpuLockup = 26
CPU lockup (exception inside exception handler)
Implementations
Sourceimpl SocResetReason
impl SocResetReason
Sourcepub const fn from_repr(discriminant: usize) -> Option<SocResetReason>
pub const fn from_repr(discriminant: usize) -> Option<SocResetReason>
Try to create Self from the raw representation